# Attributes in `ato`

This page lists all the attributes available in `ato` which effect the compiler.

## Global Attributes

::: atopile.attributes.GlobalAttributes

## Components

::: atopile.attributes.Resistor

::: atopile.attributes.CommonCapacitor

::: atopile.attributes.Capacitor

::: atopile.attributes.Inductor

::: atopile.attributes.LED

## Interfaces

::: atopile.attributes.Power
